diff --git a/res/res_pjsip.c b/res/res_pjsip.c
index e500dac0f9..d63ccd4720 100644
--- a/res/res_pjsip.c
+++ b/res/res_pjsip.c
@@ -1528,6 +1528,12 @@
 						this timer, see RFC 3261, Section 17.1.1.1.
 					</para></description>
 				</configOption>
+				<configOption name="tcp_keep_alive" default="90">
+					<synopsis>Send TCP Keep-Alive via pjproject</synopsis>
+				</configOption>
+				<configOption name="tls_keep_alive" default="90">
+					<synopsis>Send TLS Keep-Alive via pjproject</synopsis>
+				</configOption>
 				<configOption name="compact_headers" default="no">
 					<synopsis>Use the short forms of common SIP header names.</synopsis>
 				</configOption>
diff --git a/res/res_pjsip/config_system.c b/res/res_pjsip/config_system.c
index dfd92404bf..f090654607 100644
--- a/res/res_pjsip/config_system.c
+++ b/res/res_pjsip/config_system.c
@@ -52,6 +52,10 @@ struct system_config {
 	} threadpool;
 	/*! Nonzero to disable switching from UDP to TCP transport */
 	unsigned int disable_tcp_switch;
+	/*! TCP Keep-Alive via pjproject */
+	unsigned int tcp_keep_alive;
+	/*! TLS Keep-Alvie via pjproject */
+	unsigned int tls_keep_alive;
 };
 
 static struct ast_threadpool_options sip_threadpool_options = {
@@ -95,6 +99,8 @@ static int system_apply(const struct ast_sorcery *system_sorcery, void *obj)
 
 	pjsip_cfg()->tsx.t1 = system->timert1;
 	pjsip_cfg()->tsx.td = system->timerb;
+	pjsip_cfg()->tcp.keep_alive_interval = system->tcp_keep_alive;
+	pjsip_cfg()->tls.keep_alive_interval = system->tls_keep_alive;
 
 	if (system->compactheaders) {
 		extern pj_bool_t pjsip_use_compact_form;
@@ -184,6 +190,10 @@ int ast_sip_initialize_system(void)
 			OPT_UINT_T, 0, FLDSET(struct system_config, threadpool.max_size));
 	ast_sorcery_object_field_register(system_sorcery, "system", "disable_tcp_switch", "yes",
 			OPT_BOOL_T, 1, FLDSET(struct system_config, disable_tcp_switch));
+	ast_sorcery_object_field_register(system_sorcery, "system", "tcp_keep_alive", "90",
+			OPT_UINT_T, 0, FLDSET(struct system_config, tcp_keep_alive));
+	ast_sorcery_object_field_register(system_sorcery, "system", "tls_keep_alive", "90",
+			OPT_UINT_T, 0, FLDSET(struct system_config, tls_keep_alive));
 
 	ast_sorcery_load(system_sorcery);
 
